Clean Forecast Data
clean_forecast_data.RdThis function cleans and processes forecast data by filtering based on patient ID, model type, and confidence interval. It formats the data to include only ages divisible by 6 and rounds all numerical values to one decimal place. It also formats the expected BMI and expected weight.